@@ -1,11 +1,11 @@
-# $Id: Loop.pm,v 1.5 2004/11/16 07:12:42 rcaputo Exp $
+# $Id: Loop.pm,v 1.6 2004/12/18 04:24:56 rcaputo Exp $
 
 package POE::Loop;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my@r=(q$Revision: 1.5 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my@r=(q$Revision: 1.6 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 use Carp qw(croak);
 
@@ -66,7 +66,7 @@ functions are proper POE::Kernel methods.
 Each bridge first defines its own namespace and version within it.
 This way CPAN and other things can track its version.
 
-  # $Id: Loop.pm,v 1.5 2004/11/16 07:12:42 rcaputo Exp $
+  # $Id: Loop.pm,v 1.6 2004/12/18 04:24:56 rcaputo Exp $
 
   use strict;
 
@@ -75,7 +75,7 @@ This way CPAN and other things can track its version.
   package POE::Loop::YourToolkit;
 
   use vars qw($VERSION);
-  $VERSION = do {my@r=(q$Revision: 1.5 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+  $VERSION = do {my@r=(q$Revision: 1.6 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
   package POE::Kernel;
 
@@ -403,7 +403,7 @@ active.
 Stop watching a file HANDLE in a given MODE.  Stops (and possibly
 destroys) an event watcher corresponding to the HANDLE and MODE.
 
-POE::Loop::Poll manages the descriptor/mode bits out of its
+POE::Loop::IO_Poll manages the descriptor/mode bits out of its
 loop_ignore_filehandle() function.  It also performs some cleanup if a
 descriptors has been totally ignored.
 
@@ -464,7 +464,7 @@ state for a file HANDLE in a particular mode.
 
 =head1 SEE ALSO
 
-L<POE>, L<POE::Loop::Event>, L<POE::Loop::Gtk>, L<POE::Loop::Poll>,
+L<POE>, L<POE::Loop::Event>, L<POE::Loop::Gtk>, L<POE::Loop::IO_Poll>,
 L<POE::Loop::Select>, L<POE::Loop::Tk>.
 
 =head1 BUGS
