@@ -1,12 +1,12 @@
-# $Id: Aliases.pm 2245 2007-10-13 05:18:39Z rcaputo $
+# $Id: Aliases.pm,v 1.11 2004/11/16 07:12:46 rcaputo Exp $
 
 # Manage the POE::Kernel data structures necessary to keep track of
 # session aliases.
 
-package POE::Resource::Aliases;
+package POE::Resources::Aliases;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2245 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.11 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -28,9 +28,10 @@ my %kr_ses_to_alias;
 #    ...,
 #  );
 
-sub _data_alias_initialize {
+sub _data_ses_initialize {
   $poe_kernel->[KR_ALIASES] = \%kr_aliases;
 }
+use POE::API::ResLoader \&_data_ses_initialize;
 
 ### End-run leak checking.  Returns true if finalization was ok, or
 ### false if it failed.
@@ -51,14 +52,14 @@ sub _data_alias_finalize {
 
 # Add an alias to a session.
 #
-# TODO This has a potential problem: setting the same alias twice on a
+# -><- This has a potential problem: setting the same alias twice on a
 # session will increase the session's reference count twice.  Removing
 # the alias will only decrement it once.  That potentially causes
 # reference counts that never go away.  The public interface for this
 # function, alias_set(), does not allow this to occur.  We should add
 # a test to make sure it never does.
 #
-# TODO It is possible to add aliases to sessions that do not exist.
+# -><- It is possible to add aliases to sessions that do not exist.
 # The public alias_set() function prevents this from happening.
 
 sub _data_alias_add {
@@ -70,7 +71,7 @@ sub _data_alias_add {
 
 # Remove an alias from a session.
 #
-# TODO Happily allows the removal of aliases from sessions that don't
+# -><- Happily allows the removal of aliases from sessions that don't
 # exist.  This will cause problems with reference counting.
 
 sub _data_alias_remove {
@@ -137,7 +138,7 @@ __END__
 
 =head1 NAME
 
-POE::Resource::Aliases - manage session aliases for POE::Kernel
+POE::Resources::Aliases - manage session aliases for POE::Kernel
 
 =head1 SYNOPSIS
 
@@ -162,6 +163,3 @@ Probably.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
