@@ -1,12 +1,12 @@
-# $Id: SIDs.pm 2245 2007-10-13 05:18:39Z rcaputo $
+# $Id: SIDs.pm,v 1.9 2004/01/21 05:28:15 rcaputo Exp $
 
 # Session IDs: The data to maintain them, and accessors to get at them
 # sanely from other files.
 
-package POE::Resource::SIDs;
+package POE::Resources::SIDs;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2245 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.9 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -32,6 +32,7 @@ sub _data_sid_initialize {
   $poe_kernel->[KR_SESSION_IDS] = \%kr_session_ids;
   $poe_kernel->[KR_SID_SEQ] = \$kr_sid_seq;
 }
+use POE::API::ResLoader \&_data_sid_initialize;
 
 ### End-run leak checking.
 
@@ -88,7 +89,7 @@ __END__
 
 =head1 NAME
 
-POE::Resource::SIDs - session ID management for POE::Kernel
+POE::Resources::SIDs - session ID management for POE::Kernel
 
 =head1 SYNOPSIS
 
@@ -115,6 +116,3 @@ Probably.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
