@@ -1,11 +1,11 @@
-# $Id: ListenAccept.pm 2220 2007-08-19 00:59:33Z rcaputo $
+# $Id: ListenAccept.pm,v 1.30 2004/12/02 00:20:58 apocal Exp $
 
 package POE::Wheel::ListenAccept;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2220 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.30 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 use Carp qw( croak carp );
 use Symbol qw( gensym );
@@ -73,6 +73,8 @@ sub event {
       carp "ignoring unknown ListenAccept parameter '$name'";
     }
   }
+
+  $self->_define_accept_state();
 }
 
 #------------------------------------------------------------------------------
@@ -162,16 +164,6 @@ about it.
 
 This wheel neither needs nor includes a put() method.
 
-=head1 CONSTRUCTOR
-
-=over
-
-=item new
-
-new() creates a new wheel, returning the wheels reference.
-
-=back
-
 =head1 PUBLIC METHODS
 
 =over 2
@@ -263,6 +255,3 @@ Oh, probably some.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
