@@ -1,4 +1,4 @@
-# $Id: PoeBuildInfo.pm,v 1.3 2004/12/30 16:25:24 rcaputo Exp $
+# $Id: PoeBuildInfo.pm,v 1.5 2005/04/13 01:48:23 rcaputo Exp $
 
 # Build information for POE.  Moved into a library so it can be
 # required by Makefile.PL and gen-meta.perl.
@@ -27,9 +27,9 @@ sub CORE_REQUIREMENTS () {
     "POSIX"              => 1.02,
     "Socket"             => 1.7,
     "Filter::Util::Call" => 1.06,
-    "Test::More"         => 0.54,
     "File::Spec"         => 0.87,
     "Errno"              => 1.09,
+    "Test::Harness"      => 2.26,
   )
 }
 
